#
# spec file for package python-ujson
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ujson
Version:        1.35
Release:        150100.3.5.1
Summary:        JSON encoder and decoder for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/esnme/ultrajson
Source:         https://files.pythonhosted.org/packages/source/u/ujson/ujson-%{version}.tar.gz
# PATCH-FIX-UPSTREAM -- do_not_remove_build_directory_manually.patch -- https://github.com/esnme/ultrajson/issues/179
Patch0:         do_not_remove_build_directory_manually.patch
Patch1:         no-unittest2.patch
# PATCH-FIX-UPSTREAM CVE-2022-31116-surrogate-chars.patch bsc#1201255 mcepl@suse.com
# fix improper decoding of escaped surrogate characters
Patch2:         CVE-2022-31116-surrogate-chars.patch
# PATCH-FIX-UPSTREAM CVE-2022-31117-fix-double-free-str-decoding.patch bsc#[0-9]+ mcepl@suse.com
# patch from gh#ultrajson/ultrajson@9c20de0f77b3
# prevent double free on string decoding
Patch3:         CVE-2022-31117-fix-double-free-str-decoding.patch
BuildRequires:  %{python_module blist}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
UltraJSON is a JSON encoder and decoder written in pure C with
bindings for Python 2.5+ and 3. For a different C/C++ JSON
decoder experience please checkout ujson4c_, based on UltraJSON.

%prep
%setup -q -n ujson-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
pushd tests
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python tests.py
}

%files %{python_files}
%doc README.rst
%{python_sitearch}/ujson.*
%{python_sitearch}/ujson-%{version}-py*.egg-info

%changelog
* Wed Jul 27 2022 mcepl@suse.com
- (CVE-2022-31117; bsc#1201254) Add
  CVE-2022-31117-fix-double-free-str-decoding.patch avoiding
  double free while reallocating a buffer for string decoding
  (patch from gh#ultrajson/ultrajson@9c20de0f77b3).
* Wed Jul 20 2022 mcepl@suse.com
- (CVE-2022-31116; bsc#1201255) Add
  CVE-2022-31116-surrogate-chars.patch fixing improper decoding
  of escaped surrogate characters.
* Fri Aug 10 2018 tchvatal@suse.com
- Do not depend on unittest2 it is not needed:
  * no-unittest2.patch
- Really execute the tests
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL
- Run tests
- Add do_not_remove_build_directory_manually.patch
  This avoids deleting build directories that the single-spec
  macro system needs.
* Fri Dec 16 2016 jengelh@inai.de
- Replace filler words in description
* Fri Dec 16 2016 tbechtold@suse.com
- Initial packaging (version 1.35)
